@@ -4,8 +4,10 @@ macro_rules! id {
     };
 }
 
+mod once_cell;
 mod static_type_map;
 mod untyped_box;
 
+pub(crate) use once_cell::OnceCell;
 pub(crate) use static_type_map::StaticTypeMap;
 pub(crate) use untyped_box::UntypedBox;
